@@ -2,7 +2,7 @@
 
 mod char_set;
 mod column;
-mod constraint;
+mod foreign_key;
 mod index;
 mod schema;
 mod table;
@@ -10,7 +10,7 @@ mod version;
 
 pub use char_set::*;
 pub use column::*;
-pub use constraint::*;
+pub use foreign_key::*;
 pub use index::*;
 pub use schema::*;
 pub use table::*;
