@@ -1,14 +1,5 @@
-use crate::{
-    parser::Parser,
-    postgres::{
-        def::*,
-        parser::yes_or_no_to_bool,
-        query::{constraints, ColumnQueryResult},
-    },
-    Name,
-};
-
-use std::convert::{TryFrom, TryInto};
+use crate::postgres::{def::*, parser::yes_or_no_to_bool, query::ColumnQueryResult};
+use std::{collections::HashMap, convert::TryFrom};
 
 impl ColumnQueryResult {
     pub fn parse(self) -> ColumnInfo {
@@ -50,6 +41,9 @@ pub fn parse_column_type(result: &ColumnQueryResult) -> ColumnType {
     if ctype.has_bit_attr() {
         ctype = parse_bit_attributes(result.character_maximum_length, ctype);
     }
+    if ctype.has_enum_attr() {
+        ctype = parse_enum_attributes(result.udt_name.as_ref(), ctype);
+    }
 
     ctype
 }
@@ -64,21 +58,21 @@ pub fn parse_numeric_attributes(
         None => None,
         Some(num) => match u16::try_from(num) {
             Ok(num) => Some(num),
-            Err(e) => None,
+            Err(_) => None,
         },
     };
-    let numeric_precision_radix: Option<u16> = match num_precision_radix {
+    let _numeric_precision_radix: Option<u16> = match num_precision_radix {
         None => None,
         Some(num) => match u16::try_from(num) {
             Ok(num) => Some(num),
-            Err(e) => None,
+            Err(_) => None,
         },
     };
     let numeric_scale: Option<u16> = match num_scale {
         None => None,
         Some(num) => match u16::try_from(num) {
             Ok(num) => Some(num),
-            Err(e) => None,
+            Err(_) => None,
         },
     };
 
@@ -103,7 +97,7 @@ pub fn parse_string_attributes(
                 None => None,
                 Some(num) => match u16::try_from(num) {
                     Ok(num) => Some(num),
-                    Err(e) => None,
+                    Err(_) => None,
                 },
             };
         }
@@ -123,7 +117,7 @@ pub fn parse_time_attributes(datetime_precision: Option<i32>, mut ctype: ColumnT
                 None => None,
                 Some(num) => match u16::try_from(num) {
                     Ok(num) => Some(num),
-                    Err(e) => None,
+                    Err(_) => None,
                 },
             };
         }
@@ -145,7 +139,7 @@ pub fn parse_interval_attributes(
                 None => None,
                 Some(num) => match u16::try_from(num) {
                     Ok(num) => Some(num),
-                    Err(e) => None,
+                    Err(_) => None,
                 },
             };
         }
@@ -165,7 +159,7 @@ pub fn parse_bit_attributes(
                 None => None,
                 Some(num) => match u16::try_from(num) {
                     Ok(num) => Some(num),
-                    Err(e) => None,
+                    Err(_) => None,
                 },
             };
         }
@@ -174,3 +168,28 @@ pub fn parse_bit_attributes(
 
     ctype
 }
+
+pub fn parse_enum_attributes(udt_name: Option<&String>, mut ctype: ColumnType) -> ColumnType {
+    match ctype {
+        Type::Enum(ref mut def) => {
+            def.typename = match udt_name {
+                None => panic!("parse_enum_attributes(_) received an empty udt_name"),
+                Some(typename) => typename.to_string(),
+            };
+        }
+        _ => panic!("parse_enum_attributes(_) received a type that does not have EnumDef"),
+    };
+
+    ctype
+}
+
+impl ColumnInfo {
+    pub fn parse_enum_variants(mut self, enums: &HashMap<String, Vec<String>>) -> Self {
+        if let Type::Enum(ref mut enum_def) = self.col_type {
+            if let Some(def) = enums.get(&enum_def.typename) {
+                enum_def.values = def.clone()
+            }
+        }
+        self
+    }
+}
